.. include:: /_includes/wip_prolog.rst

:mod:`stix.exploit_target.weakness` Module
==========================================

.. module:: stix.exploit_target.weakness

Classes
-------

.. autoclass:: Weakness
	:show-inheritance:
	:members:
